@@ -3,6 +3,17 @@ generate_cargo.toml <- function(libname = "rextendr",
                                 patch.crates_io = NULL,
                                 extendr_deps = NULL,
                                 features = character(0)) {
+
+  # create an empty list if no dependencies are provided
+  deps <- dependencies %||% list()
+  # enabled extendr features that we need to impute into all of the
+  # dependencies
+  to_impute <- enable_features(extendr_deps, features)
+
+  for (.name in names(to_impute)) {
+    deps[[.name]] <- to_impute[[.name]]
+  }
+
   to_toml(
     package = list(
       name = libname,
@@ -13,10 +24,7 @@ generate_cargo.toml <- function(libname = "rextendr",
     lib = list(
       `crate-type` = array("cdylib", 1)
     ),
-    dependencies = purrr::list_modify(
-      dependencies %||% list(),
-      !!!enable_features(extendr_deps, features)
-    ),
+    dependencies = deps,
     `patch.crates-io` = patch.crates_io,
     `profile.perf` = list(
       inherits = "release",
